@@ -64,11 +64,9 @@ class CfnAssessmentTarget(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -231,11 +229,9 @@ class CfnAssessmentTemplate(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -473,11 +469,9 @@ class CfnResourceGroup(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
